==> nocc-1.8.3.tbz: www/nocc/lang/mk.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: mk.php 2199 2010-06-03 23:40:34Z siebrand $
 */

/** Macedonian (Македонски)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Bjankuloski06
 * @author Brest
 */

$default_date_format = '%d.%m.%Y';
$no_locale_date_format = '%d.%m.%Y';
$default_time_format = '%H:%M';
$err_user_empty = 'Нема наведено корисничко име';
$err_passwd_empty = 'Нема наведено лозинка';
$alt_delete = 'Избриши ги одбраните писма';
$alt_delete_one = 'Избриши писмо';
$alt_new_msg = 'Нови писма';
$alt_reply = 'Одговори на испраќачот';
$alt_reply_all = 'Одговори на сите';
$alt_forward = 'Проследи';
$alt_next = 'Следна';
$alt_prev = 'Претходна';
$title_next_page = 'Следна страница';
$title_prev_page = 'Претходна страница';
$title_next_msg = 'Следно писмо';
$title_prev_msg = 'Претходно писмо';
$html_theme_label = 'Облик:';
$html_welcome = 'Добредојдовте на %1$s';
$html_login = 'Најава';
$html_user_label = 'Корисник:';
$html_passwd_label = 'Лозинка';
$html_submit = 'Влези';
$html_help = 'Помош';
$html_server_label = 'Опслужувач:';
$html_wrong = 'Грешно корисничко име или лозинка';
$html_retry = 'Обиди се повторно';
$html_remember = 'Зачувај нагодувања';
$html_lang_label = 'Јазик:';
$html_msgperpage_label = 'Бр. на писма по страница:';
$html_preferences = 'Нагодувања';
$html_full_name_label = 'Целосно име:';
$html_email_address_label = 'Е-поштенска адреса:';
$html_ccself = 'Копија до себеси';
$html_hide_addresses = 'Сокриј адреси';
$html_outlook_quoting = 'Цитирање во стилот на Outlook';
$html_reply_to = 'Одговори на';
$html_use_signature = 'Користи потпис';
$html_signature = 'Потпис';
$html_signature_label = 'Потпис:';
$html_reply_leadin_label = 'Воведен блок на одговорот:';
$html_prefs_updated = 'Нагодувањата се подновени';
$html_manage_folders_link = 'Раководење со IMAP папки';
$html_manage_filters_link = 'Раководење со поштенски филтри';
$html_use_graphical_smilies = 'Користи графички смешковци';
$html_sent_folder_label = 'Копирај ги испратените писма во посебна папка:';
$html_trash_folder_label = 'Преместувај ги избришаните писма во посебна папка:';
$html_colored_quotes = 'Обоени цитати';
$html_display_struct = 'Прикажи структуриран текст';
$html_send_html_mail = 'Праќај ги писмата во HTML формат';
$html_folders = 'Папки';
$html_folders_create_failed = 'Папката не може да се создаде!';
$html_folders_sub_failed = 'Не можев да ве претплатам на папката!';
$html_folders_unsub_failed = 'Не можам да ве отипишам од папката!';
$html_folders_rename_failed = 'Папката не може да се преименува!';
$html_folders_updated = 'Папката е подновена';
$html_folder_subscribe = 'Претплати се на';
$html_folder_rename = 'Преименување';
$html_folder_create = 'Создај нова папка наречена';
$html_folder_remove = 'Откажи претплата за';
$html_folder_delete = 'Бришење';
$html_folder_to = 'до';
$html_filter_remove = 'Бришење';
$html_filter_body = 'Содржина на писмото';
$html_filter_subject = 'Наслов';
$html_filter_to = 'Поле За';
$html_filter_cc = 'Поле Копија';
$html_filter_from = 'Поле Од';
$html_filter_change_tip = 'За да замените филтер, едноставно презапишете го.';
$html_reapply_filters = 'Препримени ги сите филтри';
$html_filter_contains = 'содржи';
$html_filter_name = 'Име на филтерот';
$html_filter_action = 'Дејство на филтерот';
$html_filter_moveto = 'Премести во';
$html_select_one = '--Одберете едно--';
$html_and = 'И';
$html_new_msg_in = 'Ново писмо во';
$html_or = 'или';
$html_move = 'Премести';
$html_copy = 'Копирај';
$html_messages_to = 'избраните писма во';
$html_gotopage = 'Оди на страница';
$html_gotofolder = 'Оди во папка';
$html_other_folders = 'Список на папки';
$html_page = 'Страница';
$html_of = 'од';
$html_view_header = 'Прикажи заглавие';
$html_remove_header = 'Сокриј заглавие';
$html_inbox = 'Примени';
$html_new_msg = 'Пиши';
$html_reply = 'Одговори';
$html_reply_short = 'Одг:';
$html_reply_all = 'Одговори на сите';
$html_forward = 'Препрати';
$html_forward_short = 'Препр:';
$html_forward_info = 'Препратеното писмо ќе биде испратено како прилог кон ова писмо.';
$html_delete = 'Бриши';
$html_new = 'Ново';
$html_mark = 'Избриши';
$html_att_label = 'Податотека во прилог:';
$html_atts_label = 'Податитеки во прилог:';
$html_unknown = '[непознато]';
$html_attach = 'Приложи';
$html_attach_forget = 'Приложите ја податотеката пред да го испратите писмото!';
$html_attach_delete = 'Отстрани го одбраното';
$html_attach_none = 'Мора да одберете податотека за приложување!';
$html_sort_by = 'Сортирај по';
$html_sort = 'Подреди';
$html_from = 'Од';
$html_from_label = 'Од:';
$html_subject = 'Наслов';
$html_subject_label = 'Наслов:';
$html_date = 'Датум';
$html_date_label = 'Датум:';
$html_sent_label = 'Испратено:';
$html_wrote = 'напиша';
$html_size = 'Големина';
$html_totalsize = 'Вкупна големина';
$html_kb = 'кБ';
$html_mb = 'МБ';
$html_gb = 'ГБ';
$html_bytes = 'бајти';
$html_filename = 'Име на податотека';
$html_to = 'До';
$html_to_label = 'До:';
$html_cc = 'Копија до';
$html_cc_label = 'Копија до:';
$html_bcc_label = 'Невидлива копија за:';
$html_nosubject = 'Без предмет';
$html_send = 'Испрати';
$html_cancel = 'Откажи';
$html_no_mail = 'Нема нови писма';
$html_logout = 'Одјава';
$html_msg = 'Писмо';
$html_msgs = 'Писма';
$html_configuration = 'Опслужувачот не е правилно наместен!';
$html_priority = 'Приоритет';
$html_priority_label = 'Приоритет:';
$html_lowest = 'Најнизок';
$html_low = 'Низок';
$html_normal = 'Нормален';
$html_high = 'Висок';
$html_highest = 'Највисок';
$html_flagged = 'Означени';
$html_spam = 'Спам';
$html_spam_warning = 'Утврдено е дека оваа порака е спам.';
$html_receipt = 'Побарај потврда за прочитаност';
$html_select = 'Одбери';
$html_select_all = 'Обратен избор';
$html_select_contacts = 'Одберете контакти';
$html_loading_image = 'Вчитување на сликата';
$html_send_confirmed = 'Вашето писмо е примено за достава';
$html_no_sendaction = 'Нема назначено дејство. Обидете се со овозможување на JavaScript.';
$html_error_occurred = 'Се појави грешка';
$html_prefs_file_error = 'Не можам да ја отворам податотеката со нагодувања за да запишам.';
$html_wrap = 'Број на знаци пред пренос во нов ред, во излезните писма:';
$html_wrap_none = 'Нема рамка';
$html_usenet_separator = 'Usenet разделител ("-- \n") пред потписот';
$html_mark_as = 'Означи како';
$html_read = 'прочитано';
$html_unread = 'непрочитано';
$html_encoding_label = 'Кодирање на знаците:';
$html_add = 'Додај';
$html_contacts = '%1$s Контакти';
$html_modify = 'Измени';
$html_back = 'Назад';
$html_contact_add = 'Додај нов контакт';
$html_contact_mod = 'Измени контакт';
$html_contact_first = 'Име';
$html_contact_last = 'Презиме';
$html_contact_nick = 'Прекар';
$html_contact_mail = 'Е-пошта';
$html_contact_list = 'Контактен список на %1$s';
$html_contact_del = 'од контактниот список';
$html_contact_count = '%1$d контакти';
$html_contact_err1 = 'Максималниот број на контакти изнесува „%1$d“';
$html_contact_err2 = 'Не можете да додадете нов контакт';
$html_contact_err3 = 'Немате права на пристап до контактниот список';
$html_contact_none = 'Нема пронајдено контакти.';
$html_del_msg = 'Да ги избришам одбраните писма?';
$html_down_mail = 'Преземи';
$original_msg = '-- Ориигинално писмо --';
$to_empty = 'Полето „За“ не смее да стои празно!';
$html_images_warning = 'Надворешните слики не се прикажани за ваша безбедност.';
$html_images_display = 'Прикажи слики';
$html_smtp_error_no_conn = 'Не можам да воспоставам врска со SMTP';
$html_smtp_error_unexpected = 'Неочекуван одговор од SMTP:';
$lang_could_not_connect = 'Не можам да се поврзам со опслужувачот';
$lang_invalid_msg_num = 'Лош број на писмо';
$html_file_upload_attack = 'Можен напад преку подигање на податотека';
$html_invalid_email_address = 'Неважечка адреса';
$html_invalid_msg_per_page = 'Неважечки број на писма по страница';
$html_invalid_wrap_msg = 'Неважечка ширина на рамката на писмото';
$html_seperate_msg_win = 'Писмата во посебен прозорец';
$html_err_file_contacts = 'Не можам да ги отворам контактите за да запишам.';
$html_session_file_error = 'Не можам да ја отворам сесиската податотека за да запишам.';
$html_login_not_allowed = 'На ова корисничко име не му е дозволено да се поврзува.';
$lang_err_send_delay = 'Мора да почекате помеѓу две писма (%1$d секунди)';
$html_search = 'Пребарај';

==> nocc-1.9.1.tbz: www/nocc/lang/mk.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: mk.php 2396 2011-02-14 16:47:29Z siebrand $
 */
/** Macedonian (Македонски)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Bjankuloski06
 * @author Brest
 */

$lang_locale = 'mk_MK.UTF-8';
$default_date_format = '%d.%m.%Y';
$no_locale_date_format = '%d.%m.%Y';
$default_time_format = '%H:%M';
$err_user_empty = 'Нема наведено корисничко име';
$err_passwd_empty = 'Нема наведено лозинка';
$alt_delete = 'Избриши ги одбраните писма';
$alt_delete_one = 'Избриши писмо';
$alt_new_msg = 'Нови писма';
$alt_reply = 'Одговори на испраќачот';
$alt_reply_all = 'Одговори на сите';
$alt_forward = 'Проследи';
$alt_next = 'Следна';
$alt_prev = 'Претходна';
$title_next_page = 'Следна страница';
$title_prev_page = 'Претходна страница';
$title_next_msg = 'Следно писмо';
$title_prev_msg = 'Претходно писмо';
$html_theme_label = 'Облик:';
$html_welcome = 'Добредојдовте на %1$s';
$html_login = 'Најава';
$html_user_label = 'Корисник:';
$html_passwd_label = 'Лозинка:';
$html_submit = 'Влези';
$html_help = 'Помош';
$html_server_label = 'Опслужувач:';
$html_wrong = 'Грешно корисничко име или лозинка';
$html_retry = 'Обиди се повторно';
$html_remember = 'Запомни ги нагодувањата';
$html_lang_label = 'Јазик:';
$html_msgperpage_label = 'Бр. на писма по страница:';
$html_preferences = 'Нагодувања';
$html_full_name_label = 'Целосно име:';
$html_email_address_label = 'Е-поштенска адреса:';
$html_bccself = 'Bcc self';
$html_hide_addresses = 'Скриј адреси';
$html_outlook_quoting = 'Цитирање во стилот на Outlook';
$html_reply_to = 'Одговори на';
$html_use_signature = 'Користи потпис';
$html_signature = 'Потпис';
$html_signature_label = 'Потпис:';
$html_reply_leadin_label = 'Воведен блок на одговорот:';
$html_prefs_updated = 'Нагодувањата се подновени';
$html_manage_folders_link = 'Раководење со IMAP папки';
$html_manage_filters_link = 'Раководење со поштенски филтри';
$html_use_graphical_smilies = 'Користи графички смешковци';
$html_sent_folder_label = 'Копирај ги испратените писма во посебна папка:';
$html_trash_folder_label = 'Преместувај ги избришаните писма во посебна папка:';
$html_colored_quotes = 'Обоени цитати';
$html_display_struct = 'Прикажи структуриран текст';
$html_send_html_mail = 'Праќај ги писмата во HTML формат';
$html_folders = 'Папки';
$html_folders_create_failed = 'Папката не може да се создаде!';
$html_folders_sub_failed = 'Не можев да ве претплатам на папката!';
$html_folders_unsub_failed = 'Не можам да ве отипишам од папката!';
$html_folders_rename_failed = 'Папката не може да се преименува!';
$html_folders_updated = 'Папката е подновена';
$html_folder_subscribe = 'Претплати се на';
$html_folder_rename = 'Преименување';
$html_folder_create = 'Создај нова папка наречена';
$html_folder_remove = 'Откажи претплата за';
$html_folder_delete = 'Бришење';
$html_folder_to = 'до';
$html_filter_remove = 'Бришење';
$html_filter_body = 'Содржина на писмото';
$html_filter_subject = 'Наслов';
$html_filter_to = 'Поле За';
$html_filter_cc = 'Поле за препраќање примерок';
$html_filter_from = 'Поле Од';
$html_filter_change_tip = 'За да замените филтер, едноставно презапишете го.';
$html_reapply_filters = 'Препримени ги сите филтри';
$html_filter_contains = 'содржи';
$html_filter_name = 'Име на филтерот';
$html_filter_action = 'Дејство на филтерот';
$html_filter_moveto = 'Премести во';
$html_select_one = '--Одберете едно--';
$html_and = 'И';
$html_new_msg_in = 'Ново писмо во';
$html_or = 'или';
$html_move = 'Премести';
$html_copy = 'Копирај';
$html_messages_to = 'избраните писма во';
$html_gotopage = 'Оди на страница';
$html_gotofolder = 'Оди во папка';
$html_other_folders = 'Список на папки';
$html_page = 'Страница';
$html_of = 'од';
$html_view_header = 'Прикажи заглавие';
$html_remove_header = 'Скриј заглавие';
$html_inbox = 'Примени';
$html_new_msg = 'Пиши';
$html_reply = 'Одговори';
$html_reply_short = 'Одг:';
$html_reply_all = 'Одговори на сите';
$html_forward = 'Препрати';
$html_forward_short = 'Препр:';
$html_forward_info = 'Препратеното писмо ќе биде испратено како прилог кон ова писмо.';
$html_delete = 'Бриши';
$html_new = 'Ново';
$html_mark = 'Избриши';
$html_att_label = 'Податотека во прилог:';
$html_atts_label = 'Податитеки во прилог:';
$html_unknown = '[непознато]';
$html_part_x = 'Дел %s';
$html_attach = 'Приложи';
$html_attach_forget = 'Приложите ја податотеката пред да го испратите писмото!';
$html_attach_delete = 'Отстрани го одбраното';
$html_attach_none = 'Мора да одберете податотека за приложување!';
$html_sort_by = 'Подреди по';
$html_sort = 'Подреди';
$html_from = 'Од';
$html_from_label = 'Од:';
$html_subject = 'Наслов';
$html_subject_label = 'Наслов:';
$html_date = 'Датум';
$html_date_label = 'Датум:';
$html_sent_label = 'Испратено:';
$html_wrote = 'напиша';
$html_size = 'Големина';
$html_totalsize = 'Вкупна големина';
$html_kb = 'кБ';
$html_mb = 'МБ';
$html_gb = 'ГБ';
$html_bytes = 'бајти';
$html_filename = 'Име на податотеката';
$html_to = 'До';
$html_to_label = 'До:';
$html_cc = 'Копија до';
$html_cc_label = 'Примерок и до:';
$html_bcc_label = 'Невидлива копија за:';
$html_nosubject = 'Без предмет';
$html_send = 'Испрати';
$html_cancel = 'Откажи';
$html_no_mail = 'Нема нови писма';
$html_logout = 'Одјава';
$html_msg = 'Писмо';
$html_msgs = 'Писма';
$html_configuration = 'Опслужувачот не е правилно наместен!';
$html_priority = 'Приоритет';
$html_priority_label = 'Приоритет:';
$html_lowest = 'Најнизок';
$html_low = 'Низок';
$html_normal = 'Нормален';
$html_high = 'Висок';
$html_highest = 'Највисок';
$html_flagged = 'Означени';
$html_spam = 'Спам';
$html_spam_warning = 'Утврдено е дека оваа порака е спам.';
$html_receipt = 'Побарај потврда за прочитаност';
$html_select = 'Одбери';
$html_select_all = 'Обратен избор';
$html_select_contacts = 'Одберете контакти';
$html_loading_image = 'Вчитување на сликата';
$html_send_confirmed = 'Вашето писмо е примено за достава';
$html_no_sendaction = 'Нема назначено дејство. Обидете се со овозможување на JavaScript.';
$html_error_occurred = 'Се појави грешка';
$html_prefs_file_error = 'Не можам да ја отворам податотеката со нагодувања за да запишам.';
$html_wrap = 'Број на знаци пред пренос во нов ред, во излезните писма:';
$html_wrap_none = 'Нема рамка';
$html_usenet_separator = 'Usenet разделител ("-- \n") пред потписот';
$html_mark_as = 'Означи како';
$html_read = 'прочитано';
$html_unread = 'непрочитано';
$html_encoding_label = 'Кодирање на знаците:';
$html_add = 'Додај';
$html_contacts = '%1$s Контакти';
$html_modify = 'Измени';
$html_back = 'Назад';
$html_contact_add = 'Додај нов контакт';
$html_contact_mod = 'Измени контакт';
$html_contact_first = 'Име';
$html_contact_last = 'Презиме';
$html_contact_nick = 'Прекар';
$html_contact_mail = 'Е-пошта';
$html_contact_list = 'Контактен список на %1$s';
$html_contact_del = 'од контактниот список';
$html_contact_count = '%1$d контакти';
$html_contact_err1 = 'Максималниот број на контакти изнесува „%1$d“';
$html_contact_err2 = 'Не можете да додадете нов контакт';
$html_contact_err3 = 'Немате права на пристап до контактниот список';
$html_contact_none = 'Нема пронајдено контакти.';
$html_del_msg = 'Да ги избришам одбраните писма?';
$html_down_mail = 'Преземи';
$original_msg = '-- Ориигинално писмо --';
$to_empty = 'Полето „За“ не смее да стои празно!';
$html_images_warning = 'Надворешните слики не се прикажани за ваша безбедност.';
$html_images_display = 'Прикажи слики';
$html_smtp_error_no_conn = 'Не можам да воспоставам врска со SMTP';
$html_smtp_error_unexpected = 'Неочекуван одговор од SMTP:';
$lang_could_not_connect = 'Не можам да се поврзам со опслужувачот';
$lang_invalid_msg_num = 'Лош број на писмо';
$html_file_upload_attack = 'Можен напад преку подигање на податотека';
$html_invalid_email_address = 'Неважечка адреса';
$html_invalid_msg_per_page = 'Неважечки број на писма по страница';
$html_invalid_wrap_msg = 'Неважечка ширина на рамката на писмото';
$html_seperate_msg_win = 'Писмата во посебен прозорец';
$html_err_file_contacts = 'Не можам да ги отворам контактите за да запишам.';
$html_session_file_error = 'Не можам да ја отворам сесиската податотека за да запишам.';
$html_login_not_allowed = 'На ова корисничко име не му е дозволено да се поврзува.';
$lang_err_send_delay = 'Мора да почекате помеѓу две писма (%1$d секунди)';
$html_search = 'Пребарај';
